module module_draw
  use netcdf
  use kwm_plot_utilities
  implicit none

  integer :: ncid

  type var_type
     character(len=256) :: name
     character(len=256) :: units
     character(len=256) :: description
     integer            :: xdim
     real, pointer, dimension(:) :: data
     integer            :: color_index
  end type var_type

contains

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

  subroutine error_handler(status, failure, success)
    !
    ! Check the error flag from a NetCDF function call, and print appropriate
    ! error message.
    !
    implicit none
    integer,                    intent(in) :: status
    character(len=*), optional, intent(in) :: failure
    character(len=*), optional, intent(in) :: success

    if (status .ne. NF90_NOERR) then
       write(*,'(/,A)') nf90_strerror(status)
       if (present(failure)) then
          write(*,'(/," ***** ", A,/)') failure
       endif
       stop 'Stopped'
    endif

    if (present(success)) then
       write(*,'(A)') success
    endif

  end subroutine error_handler

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

  subroutine open_output_file(filename)
    implicit none
    character(len=*), intent(in) :: filename
    integer :: iret
    iret = nf90_open(filename, NF90_NOWRITE, ncid)
    call error_handler(iret, "Problem opening "//filename, "Success opening "//filename)

  end subroutine open_output_file

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

  subroutine get_var(name, level, var)
    implicit none
    character(len=*), intent(in)  :: name
    integer,          intent(in)  :: level
    type(var_type),   intent(out) :: var

    integer :: i
    integer :: iret
    integer :: varid
    integer :: ndims
    integer, dimension(NF90_MAX_VAR_DIMS) :: dimids
    character(len=NF90_MAX_NAME) :: dimname
    integer, dimension(NF90_MAX_VAR_DIMS) :: dimlen
    integer, dimension(NF90_MAX_VAR_DIMS) :: nstart, ncount
    character(len=3) :: hlevel

    ! Find the varid
    iret = nf90_inq_varid(ncid, name, varid)
    call error_handler(iret, "Problem finding varid for "//name, "Found varid for "//name)

    ! Find the shape of the variable.
    iret = nf90_inquire_variable(ncid, varid, ndims=ndims, dimids=dimids)
    call error_handler(iret, "Problem inquiring on variable "//name, "Successful inquire on variable "//name)

    do i = 1, ndims

       iret = nf90_inquire_dimension(ncid, dimids(i), name=dimname, len=dimlen(i))
       call error_handler(iret, "Problem getting dimension for variable "//name, "Found dimension '"//trim(dimname)//"' for variable "//name)

       if (dimname == "Time") then
!KWM          nstart(i) = startindex
!KWM          ncount(i) = endindex-startindex+1
          nstart(i) = 1
          ncount(i) = dimlen(i)
          var%xdim = dimlen(i)

       else
!KWM          nstart(i) = 1
!KWM          ncount(i) = dimlen(i)
          nstart(i) = level
          ncount(i) = 1

       endif

    enddo

    ! Allocate space
    allocate(var%data(var%xdim))

    ! Read the variable
    iret = nf90_get_var(ncid, varid, var%data, start=nstart(1:ndims), count=ncount(1:ndims) )
    call error_handler(iret, "Problem getting varaible "//name, "Got variable "//name)

    ! Get the units
    iret = nf90_get_att(ncid, varid, "units", var%units)
    call error_handler(iret, "Problem getting 'units' attribute "//name, "got units for "//name)

    ! Get the description
    iret = nf90_get_att(ncid, varid, "description", var%description)
    call error_handler(iret, "Problem getting 'description' attribute "//name, "got description for "//name)

    if (level > 0) then
       write(hlevel,'(I3)') level
       var%name = name // ":  Level " // hlevel
    else
       var%name = name
    endif
    
  end subroutine get_var

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------
  subroutine clear_var(var)
    implicit none
    type(var_type) :: var
    var%name = ""
    var%units = ""
    var%description = ""
    var%xdim = -99999
    deallocate(var%data)
    nullify(var%data)
    var%color_index = -99999
  end subroutine clear_var

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

  subroutine get_times(hdates, xhour)
    use kwm_date_utilities
    implicit none
    character(len=12), pointer, dimension(:) :: hdates
    real,              pointer, dimension(:) :: xhour

    integer :: i
    integer :: idt
    integer :: iret
    integer :: varid
    integer :: ndims
    integer, dimension(NF90_MAX_VAR_DIMS) :: dimids
    character(len=NF90_MAX_NAME) :: dimname
    integer, dimension(NF90_MAX_VAR_DIMS) :: dimlen
    integer, dimension(NF90_MAX_VAR_DIMS) :: nstart, ncount

    integer :: xdim

    character(len=5), parameter :: name = "Times"

    ! Find the varid
    iret = nf90_inq_varid(ncid, name, varid)
    call error_handler(iret, "Problem finding varid for "//name, "Found varid for "//name)

    ! Find the shape of the variable.
    iret = nf90_inquire_variable(ncid, varid, ndims=ndims, dimids=dimids)
    call error_handler(iret, "Problem inquiring on variable "//name, "Successful inquire on variable "//name)

    do i = 1, ndims

       iret = nf90_inquire_dimension(ncid, dimids(i), name=dimname, len=dimlen(i))
       call error_handler(iret, "Problem getting dimension for variable "//name, "Found dimension '"//trim(dimname)//"' for variable "//name)

       print*, 'dimension '//trim(dimname)//' = ', dimlen(i)
       if (dimname == "Time") then
          nstart(i) = 1
          ncount(i) = dimlen(i)
          xdim = dimlen(i)
       else
          nstart(i) = 1
          ncount(i) = dimlen(i)

       endif

    enddo

    ! Allocate space
    allocate(hdates(xdim))
    allocate(xhour(xdim))

    ! Read the variable
    iret = nf90_get_var(ncid, varid, hdates, start=nstart(1:ndims), count=ncount(1:ndims) )
    call error_handler(iret, "Problem getting varaible "//name, "Got variable "//name)

    ! Fill in xhour
    do i = 1, xdim
       call geth_idts(hdates(i), hdates(1), idt)
       xhour(i) = real(idt)/60.0
    enddo

  end subroutine get_times

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

  subroutine draw_var(var, xhour, hdates, overlay, overlay2)
    implicit none

    type(var_type),              intent(in)  :: var
    real,              pointer, dimension(:) :: xhour
    character(len=12), pointer, dimension(:) :: hdates
    type(var_type),              optional    :: overlay
    type(var_type),              optional    :: overlay2

    real :: varmin, varmax
    integer :: expn, irange
    integer :: indx
    integer :: indxo
    integer :: indxo2

    real, parameter :: xtimewin = 2*7*24 ! two weeks, in hours.
    integer :: nframe, nframes
    integer :: period
    integer :: ierr
    integer :: save_color_index
    real    :: frame_height = 0.115

    real    :: wl, wr, wb, wt, xl, xr, xb, xt

    nframes = int(xhour(var%xdim)/xtimewin)

    varmin = minval(var%data, mask=(var%data>-1.E25))
    varmax = maxval(var%data, mask=(var%data>-1.E25))

    if (present(overlay)) then
       varmin = min(varmin, minval(overlay%data, mask=(overlay%data>-1.E25)))
       varmax = max(varmax, maxval(overlay%data, mask=(overlay%data>-1.E25)))
       indxo = 1
    endif

    if (present(overlay2)) then
       varmin = min(varmin, minval(overlay2%data, mask=(overlay2%data>-1.E25)))
       varmax = max(varmax, maxval(overlay2%data, mask=(overlay2%data>-1.E25)))
       indxo2 = 1
    endif
    
    call find_good_range_n(varmin, varmax, expn, irange)
    print*, 'varmin, varmax, expn, irange = ', varmin, varmax, expn, irange

    ! Annotate
    call set(0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 1)

    ! call gflas1(20)

    call pcseti("CC", var%color_index)
    call pchiqu(.1, .975, var%name, 0.01, 0.0, -1.0)

    if (present(overlay)) then
       call pcseti("CC", overlay%color_index)
       call pchiqu(.4, .975, overlay%name, 0.01, 0.0, -1.0)
    endif

    if (present(overlay2)) then
       call pcseti("CC", overlay2%color_index)
       call pchiqu(.7, .975, overlay2%name, 0.01, 0.0, -1.0)
    endif

    call pcseti("CC", save_color_index)

    ! call gflas2

    ! Split us up into two-week periods:
    period = 1
    indx = 1
    nframe = 1

    call gqplci (ierr, save_color_index)

    ! call gaseti("LTY", 1)
    call gasetc("XLF", "(A0)")
    call gasetc("YLF", "(F10.4)")
    call gaseti("YLS", 7)

    wl = 0.1
    wr = 0.9
    do period = 1, nframes

       call gsplci(save_color_index)
       wb = 0.945-(nframe*frame_height)
       wt = 0.93-((nframe-1)*frame_height)
       xl = xtimewin*(period-1)
       xr = xtimewin*period
       call set(wl, wr, wb, wt, xl, xr, varmin, varmax, 1)
       call periml(0, 0, irange, 0)

       call pcseti("CC", save_color_index)
       call gsclip(0)
       call pchiqu(xl, varmin, "~V-15~"//hdates(indx), 0.008, 0., -1.)
       call gsclip(1)
       call draw_the_curve(var, xhour, indx, xtimewin, period)

       if (present(overlay)) then
          call draw_the_curve(overlay, xhour, indxo, xtimewin, period)
       endif
       
       if (present(overlay2)) then
          call draw_the_curve(overlay2, xhour, indxo2, xtimewin, period)
       endif

       call gsplci(save_color_index)

       if (mod(period, 8) == 0) then

          ! Annotate
          call set(0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 1)

          call pcseti("CC", var%color_index)
          call pchiqu(.1, .975, var%name, 0.01, 0.0, -1.0)

          if (present(overlay)) then
             call pcseti("CC", overlay%color_index)
             call pchiqu(.4, .975, overlay%name, 0.01, 0.0, -1.0)
          endif

          if (present(overlay2)) then
             call pcseti("CC", overlay2%color_index)
             call pchiqu(.7, .975, overlay2%name, 0.01, 0.0, -1.0)
          endif

          call pcseti("CC", save_color_index)

          call frame
          nframe = 0
       endif
       nframe = nframe + 1

    enddo

    ! Annotate
    call set(0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 1)

    call pcseti("CC", var%color_index)
    call pchiqu(.1, .975, var%name, 0.01, 0.0, -1.0)

    if (present(overlay)) then
       call pcseti("CC", overlay%color_index)
       call pchiqu(.4, .975, overlay%name, 0.01, 0.0, -1.0)
    endif

    if (present(overlay2)) then
       call pcseti("CC", overlay2%color_index)
       call pchiqu(.7, .975, overlay2%name, 0.01, 0.0, -1.0)
    endif

    call pcseti("CC", save_color_index)

    call gsplci(save_color_index)
    call frame()
  end subroutine draw_var

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

  subroutine draw_var_nmlz(var, xhour, hdates, overlay, overlay2)
    implicit none

    type(var_type), intent(in)  :: var
    real, pointer, dimension(:) :: xhour
    character(len=12), pointer, dimension(:) :: hdates
    type(var_type), optional    :: overlay
    type(var_type), optional    :: overlay2

    real :: varmin, varmax
    real :: varmino, varmaxo
    real :: varmino2, varmaxo2
    integer :: expn, irange
    integer :: expno, irangeo
    integer :: expno2, irangeo2
    integer :: indx
    integer :: indxo
    integer :: indxo2

    real, parameter :: xtimewin = 2*7*24 ! two weeks, in hours.
    integer :: nframe, nframes
    integer :: period
    integer :: ierr
    integer :: save_color_index
    real    :: frame_height = 0.115

    real    :: wl, wr, wb, wt, xl, xr, xb, xt
    real, allocatable, dimension(:) :: datatmp
    real, allocatable, dimension(:) :: datatmpo
    real, allocatable, dimension(:) :: datatmpo2
    

    nframes = int(xhour(var%xdim)/xtimewin)

    varmin = minval(var%data, mask=(var%data>-1.E25))
    varmax = maxval(var%data, mask=(var%data>-1.E25))

    call find_good_range_n(varmin, varmax, expn, irange)
    print*, 'irange = ', irange
    allocate(datatmp(var%xdim))
    datatmp = (var%data - varmin)/(varmax-varmin)

    if (present(overlay)) then
       varmino = minval(overlay%data, mask=(overlay%data>-1.E25))
       varmaxo = maxval(overlay%data, mask=(overlay%data>-1.E25))
       call find_good_range_n(varmino, varmaxo, expno, irangeo)
       print*, 'irangeo = ', irangeo
       indxo = 1
       allocate(datatmpo(var%xdim))
       datatmpo = (overlay%data - varmino)/(varmaxo-varmino)
    endif

    if (present(overlay2)) then
       varmino2 = minval(overlay2%data, mask=(overlay2%data>-1.E25))
       varmaxo2 = maxval(overlay2%data, mask=(overlay2%data>-1.E25))
       call find_good_range_n(varmino2, varmaxo2, expno2, irangeo2)
       indxo2 = 1
       allocate(datatmpo2(var%xdim))
       datatmpo2 = (overlay2%data - varmino2)/(varmaxo2-varmino2)
    endif

    ! Annotate
    call set(0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 1)

    ! call gflas1(21)

    call pcseti("CC", var%color_index)
    call pchiqu(.1, .975, var%name, 0.01, 0.0, -1.0)

    if (present(overlay)) then
       call pcseti("CC", overlay%color_index)
       call pchiqu(.4, .975, overlay%name, 0.01, 0.0, -1.0)
    endif

    if (present(overlay2)) then
       call pcseti("CC", overlay2%color_index)
       call pchiqu(.7, .975, overlay2%name, 0.01, 0.0, -1.0)
    endif

    call pcseti("CC", save_color_index)

    ! call gflas2

    ! Split us up into two-week periods:
    period = 1
    indx = 1
    nframe = 1

    call gqplci (ierr, save_color_index)

    ! call gaseti("LTY", 1)
    call gasetc("XLF", "(A0)")
    call gasetc("YLF", "(F10.4)")
    call gaseti("YLS", 7)

    xl = 0.1
    xr = 0.9
    do period = 1, nframes

       call gsplci(save_color_index)
       xb = 0.945-(nframe*frame_height)
       xt = 0.93-((nframe-1)*frame_height)
       wl = xtimewin*(period-1)
       wr = xtimewin*period

       call gaseti("YLO", 20);
       call pcseti("CC", var%color_index)
       call set(xl, xr, xb, xt, wl, wr, varmin, varmax, 1)
       call periml(0, 0, irange, 0)

       call set(xl, xr, xb, xt, wl, wr, 0.0, 1.0, 1)
       call pcseti("CC", save_color_index)

       call gsclip(0)
       call pchiqu(wl, 0.0, "~V-15~"//hdates(indx), 0.008, 0., -1.)
       call gsclip(1)

       call draw_the_curve_nmlz(var%xdim, var%color_index, datatmp, xhour, indx, xtimewin, period)

       if (present(overlay)) then
          call gaseti("YLO", 1);

          call pcseti("CC", overlay%color_index)
          call set(xl, xr, xb, xt, wl, wr, varmino, varmaxo, 1)
          call periml(0, 0, irangeo, 0)
          call set(xl, xr, xb, xt, wl, wr, 0.0, 1.0, 1)

          call draw_the_curve_nmlz(var%xdim, overlay%color_index, datatmpo, xhour, indxo, xtimewin, period)
       endif
       
       if (present(overlay2)) then
          call draw_the_curve_nmlz(var%xdim, overlay2%color_index, datatmpo2, xhour, indxo2, xtimewin, period)
       endif

       call gsplci(save_color_index)

       if (mod(period, 8) == 0) then

          ! Annotate
          call set(0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 1)

          call pcseti("CC", var%color_index)
          call pchiqu(.1, .975, var%name, 0.01, 0.0, -1.0)

          if (present(overlay)) then
             call pcseti("CC", overlay%color_index)
             call pchiqu(.4, .975, overlay%name, 0.01, 0.0, -1.0)
          endif

          if (present(overlay2)) then
             call pcseti("CC", overlay2%color_index)
             call pchiqu(.7, .975, overlay2%name, 0.01, 0.0, -1.0)
          endif

          call pcseti("CC", save_color_index)

          call frame
          nframe = 0
       endif
       nframe = nframe + 1

    enddo

    ! call gflas3(21)
    call gsplci(save_color_index)
    ! Annotate
    call set(0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 1)

    call pcseti("CC", var%color_index)
    call pchiqu(.1, .975, var%name, 0.01, 0.0, -1.0)

    if (present(overlay)) then
       call pcseti("CC", overlay%color_index)
       call pchiqu(.4, .975, overlay%name, 0.01, 0.0, -1.0)
    endif

    if (present(overlay2)) then
       call pcseti("CC", overlay2%color_index)
       call pchiqu(.7, .975, overlay2%name, 0.01, 0.0, -1.0)
    endif

    call pcseti("CC", save_color_index)

    call frame()
  end subroutine draw_var_nmlz

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

  subroutine draw_the_curve(var, xhour, indx, xtimewin, period)
    implicit none
    type(var_type), intent(in) :: var
    real, pointer, dimension(:) :: xhour
    integer, intent(inout) :: indx
    real, intent(in) :: xtimewin
    integer, intent(in) :: period
    logical :: pd

    call gsplci(var%color_index)

    pd = .FALSE.

    do
       if (var%data(indx) > -1.E25) then
          if (pd) then
             call vector(xhour(indx), var%data(indx))
          else
             call frstpt(xhour(indx), var%data(indx))
             pd = .TRUE.
          endif
       else
          if (pd) then
             pd = .FALSE.
             call plotif(0., 0., 2)
          endif
       endif
             
       indx = indx + 1
       if (xhour(indx) > xtimewin*period) exit
    enddo
    call plotif(0., 0., 2)

  end subroutine draw_the_curve

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

  subroutine draw_the_curve_nmlz(xdim, icol, data, xhour, indx, xtimewin, period)
    implicit none
    integer, intent(in) :: xdim
    integer, intent(in) :: icol
    real, dimension(xdim), intent(in) :: data
    real, dimension(xdim), intent(in) :: xhour
    integer, intent(inout) :: indx
    real, intent(in) :: xtimewin
    integer, intent(in) :: period
    logical :: pd

    call gsplci(icol)

    pd = .FALSE.

    do
       if (data(indx) > -1.E25) then
          if (pd) then
             call vector(xhour(indx), data(indx))
          else
             call frstpt(xhour(indx), data(indx))
             pd = .TRUE.
          endif
       else
          if (pd) then
             pd = .FALSE.
             call plotif(0., 0., 2)
          endif
       endif
             
       indx = indx + 1
       if (xhour(indx) > xtimewin*period) exit
    enddo
    call plotif(0., 0., 2)

  end subroutine draw_the_curve_nmlz

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

  subroutine find_good_range_n(ymin, ymax, expn, irange)
    !
    ! Given an initial <ymin> and <ymax> (minimum and maximum of some field), 
    ! return "good round numbers" for <ymin> and <ymax>.
    ! <irange> is the number of steps between our good round <ymin> and good round <ymax>
    ! <expn> is the power-of-ten scaling applied to get our round numbers.
    !
    ! There are <irange> steps of size 10.0**<expn> between output values of <ymin> and <ymax>
    !
    implicit none
    real, intent(inout)  :: ymin
    real, intent(inout)  :: ymax
    integer, intent(out) :: expn
    integer, intent(out) :: irange

    integer :: iymin
    integer :: iymax

    expn = floor(log10(ymax-ymin)) - 1

    iymin = floor   ( (10.0**(real(-expn))) * ymin )
    iymax = ceiling ( (10.0**(real(-expn))) * ymax )
    irange = (iymax-iymin)
  
    ! If we've got too many steps between iymin and iymax, 
    ! then shift to the next power-of-ten for our scaling.
    if (irange > 5) then
       iymin = floor  (real(iymin)*0.1)
       iymax = ceiling(real(iymax)*0.1)
       expn = expn + 1
       irange = (iymax-iymin)
    endif

    ymin = real(iymin) * 10.0**(real(expn))
    ymax = real(iymax) * 10.0**(real(expn))

  end subroutine find_good_range_n

!---------------------------------------------------------------------------------------
!---------------------------------------------------------------------------------------

end module module_draw

program draw
  use module_draw
  implicit none

  character(len=12), pointer, dimension(:) :: hdates
  real,              pointer, dimension(:) :: xhour
  type(var_type) :: var1, var2, var3, var4, var5, var6
  integer :: i
  real :: varmin, varmax
  integer :: expn, irange

  call open_output_file("OUTPUT.nc")

  call get_times(hdates, xhour)

  print*, 'shape(hdates) = ', shape(hdates)

  call kwm_init_ncargks("draw.cgm")

  call gaseti("LTY", 1)


  !==============================================================

  call get_var("PRCP",  1, var1)
  call get_var("SNEQV", 1, var2)

  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")

  call draw_var_nmlz(var1,  xhour, hdates, overlay=var2)

  call clear_var(var1)
  call clear_var(var2)

  !==============================================================

  call get_var("STC", 1, var1)
  call get_var("STC", 2, var2)
  call get_var("STC", 3, var3)

  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green3")

  call draw_var(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("SNICE", 1, var1)
  call get_var("SNICE", 2, var2)
  call get_var("SNICE", 3, var3)

  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green3")

  call draw_var(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("SNLIQ", 1, var1)
  call get_var("SNLIQ", 2, var2)
  call get_var("SNLIQ", 3, var3)

  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green3")

  call draw_var(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("O2AIR",  1, var1)
  call get_var("CO2AIR", 1, var2)
  call get_var("FOLN",   1, var3)

  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green3")

  call draw_var_nmlz(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("O2AIR",  1, var1)
  call get_var("SFCPRS", 1, var2)
  call get_var("CO2AIR", 1, var3)

  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green3")

  call draw_var_nmlz(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("SMC", 1, var4)
  call get_var("SMC", 2, var5)
  call get_var("SMC", 3, var6)
  var4%color_index = color_index("blue")
  var5%color_index = color_index("red")
  var6%color_index = color_index("green3")

  call draw_var(var4,  xhour, hdates, overlay=var5, overlay2=var6)

  call clear_var(var4)
  call clear_var(var5)
  call clear_var(var6)

  !==============================================================

  call get_var("SMC", 1, var1)
  call get_var("FWET",1, var2)
  call get_var("CANLIQ",1, var3)
  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green4")

  call draw_var_nmlz(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("CANICE", 1, var1)
  call get_var("FWET",   1, var2)
  call get_var("CANLIQ", 1, var3)
  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green4")

  call draw_var_nmlz(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("TAH", 1, var4)
  call get_var("STC", 1, var5)
  call get_var("SFCTMP", 1, var6)
  var4%color_index = color_index("blue")
  var5%color_index = color_index("red")
  var6%color_index = color_index("green3")

  call draw_var(var4,  xhour, hdates, overlay=var5, overlay2=var6)

  call clear_var(var4)
  call clear_var(var5)
  call clear_var(var6)

  !==============================================================

  call get_var("TAH", 1, var1)
  call get_var("EAH", 1, var2)
  call get_var("Q2",  1, var3)
  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green")

  call draw_var_nmlz(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("TAH",    1, var1)
  call get_var("TV",     1, var2)
  call get_var("SFCTMP", 1, var3)
  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green")

  call draw_var(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("STC", 1, var1)
  call get_var("SNOWT", 3, var2)
  call get_var("SNOWT", 2, var3)

  where (var2%data < 1) var2%data = -1.E36
  where (var3%data < 1) var3%data = -1.E36

  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green3")

  call draw_var(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("SFCTMP", 0, var1)
  call get_var("SNOWT", 3, var2)
  call get_var("STC",   1, var3)

  where (var2%data < 1) var2%data = -1.E36
  ! where (var3%data < 1) var3%data = -1.E36

  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  var3%color_index = color_index("green3")

  call draw_var(var1,  xhour, hdates, overlay=var2, overlay2=var3)

  call clear_var(var1)
  call clear_var(var2)
  call clear_var(var3)

  !==============================================================

  call get_var("COSZ", 0, var1)
  call get_var("SOLDN", 0, var2)
  where (var1%data < 0) var1%data = 0
  var1%color_index = color_index("blue")
  var2%color_index = color_index("red")
  call draw_var_nmlz(var1,  xhour, hdates, overlay=var2)
  call clear_var(var1)
  call clear_var(var2)
  
  !==============================================================

  call kwm_close_ncargks


end program draw

